rename API cs_disasm_dyn() to cs_disasm_ex(), and intentionally breaks compatibility with 1.0
diff --git a/tests/test_mips.c b/tests/test_mips.c
index 53f3bc1..0a77785 100644
--- a/tests/test_mips.c
+++ b/tests/test_mips.c
@@ -101,7 +101,7 @@
 		if (cs_open(platforms[i].arch, platforms[i].mode, &handle))
 			return;
 
-		size_t count = cs_disasm_dyn(handle, platforms[i].code, platforms[i].size, address, 0, &insn);
+		size_t count = cs_disasm_ex(handle, platforms[i].code, platforms[i].size, address, 0, &insn);
 		if (count) {
 			printf("****************\n");
 			printf("Platform: %s\n", platforms[i].comment);
@@ -115,7 +115,7 @@
 			}
 			printf("0x%"PRIx64":\n", insn[j-1].address + insn[j-1].size);
 
 			// free memory allocated by cs_disasm_dyn()
 			cs_free(insn, count);
 		} else {
 			printf("****************\n");
@@ -115,7 +115,7 @@
 			printf("0x%"PRIx64":\n", insn[j-1].address + insn[j-1].size);
 
-			// free memory allocated by cs_disasm_dyn()
+			// free memory allocated by cs_disasm_ex()
 			cs_free(insn, count);
 		} else {